"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var base_1 = require("@rmwc/base");
var icon_1 = require("@rmwc/icon");
var ripple_1 = require("@rmwc/ripple");
var foundation_1 = require("./foundation");
/** An IconButton component that can also be used as a toggle. */
exports.IconButton = React.forwardRef(function IconButton(_a, ref) {
    var rest = tslib_1.__rest(_a, []);
    if (rest.onIcon) {
        return React.createElement(IconButtonToggle, tslib_1.__assign({}, rest, { ref: ref }));
    }
    return React.createElement(IconButtonRoot, tslib_1.__assign({ "aria-hidden": "true", tag: "button" }, rest, { ref: ref }));
});
exports.IconButton.displayName = 'IconButton';
var IconButtonToggle = React.forwardRef(function IconButtonToggle(props, ref) {
    var icon = props.icon, onIcon = props.onIcon, rest = tslib_1.__rest(props, ["icon", "onIcon"]);
    var _a = foundation_1.useIconButtonFoundation(props), isOn = _a.isOn, rootEl = _a.rootEl;
    return (React.createElement(IconButtonToggleRoot, tslib_1.__assign({ "aria-pressed": isOn, "aria-hidden": "true" }, rootEl.props(rest), { tag: "button", ref: ref }),
        React.createElement(IconButtonIcon, { icon: icon }),
        React.createElement(IconButtonIcon, { icon: onIcon, on: true })));
});
/*********************************************************************
 * Bits
 *********************************************************************/
var IconButtonRoot = ripple_1.withRipple({
    surface: false,
    unbounded: true
})(React.forwardRef(function IconButtonRoot(props, ref) {
    var checked = props.checked, rest = tslib_1.__rest(props, ["checked"]);
    var className = base_1.useClassNames(props, [
        'mdc-icon-button',
        {
            'mdc-icon-button--on': checked
        }
    ]);
    return (React.createElement(icon_1.Icon, tslib_1.__assign({ role: "button", tabIndex: 0 }, rest, { className: className, ref: ref })));
}));
IconButtonRoot.displayName = 'IconButtonRoot';
var IconButtonToggleRoot = ripple_1.withRipple({
    surface: false,
    unbounded: true
})(React.forwardRef(function IconButtonToggleRoot(props, ref) {
    var checked = props.checked, rest = tslib_1.__rest(props, ["checked"]);
    var className = base_1.useClassNames(props, [
        'mdc-icon-button',
        {
            'mdc-icon-button--on': checked
        }
    ]);
    return (React.createElement(base_1.Tag, tslib_1.__assign({ tag: "button", role: "button", tabIndex: 0 }, rest, { className: className, ref: ref })));
}));
IconButtonToggleRoot.displayName = 'IconButtonToggleRoot';
var IconButtonIcon = React.memo(function IconButtonIcon(props) {
    var on = props.on, rest = tslib_1.__rest(props, ["on"]);
    var className = base_1.useClassNames(props, [
        'mdc-icon-button__icon',
        {
            'mdc-icon-button__icon--on': props.on
        }
    ]);
    return React.createElement(icon_1.Icon, tslib_1.__assign({}, rest, { className: className }));
});
IconButtonIcon.displayName = 'IconButtonIcon';
