import { __assign, __rest } from "tslib";
import * as React from 'react';
import { Tag, useClassNames } from '@rmwc/base';
import { Icon } from '@rmwc/icon';
import { withRipple } from '@rmwc/ripple';
import { useIconButtonFoundation } from './foundation';
/** An IconButton component that can also be used as a toggle. */
export var IconButton = React.forwardRef(function IconButton(_a, ref) {
    var rest = __rest(_a, []);
    if (rest.onIcon) {
        return React.createElement(IconButtonToggle, __assign({}, rest, { ref: ref }));
    }
    return React.createElement(IconButtonRoot, __assign({ "aria-hidden": "true", tag: "button" }, rest, { ref: ref }));
});
IconButton.displayName = 'IconButton';
var IconButtonToggle = React.forwardRef(function IconButtonToggle(props, ref) {
    var icon = props.icon, onIcon = props.onIcon, rest = __rest(props, ["icon", "onIcon"]);
    var _a = useIconButtonFoundation(props), isOn = _a.isOn, rootEl = _a.rootEl;
    return (React.createElement(IconButtonToggleRoot, __assign({ "aria-pressed": isOn, "aria-hidden": "true" }, rootEl.props(rest), { tag: "button", ref: ref }),
        React.createElement(IconButtonIcon, { icon: icon }),
        React.createElement(IconButtonIcon, { icon: onIcon, on: true })));
});
/*********************************************************************
 * Bits
 *********************************************************************/
var IconButtonRoot = withRipple({
    surface: false,
    unbounded: true
})(React.forwardRef(function IconButtonRoot(props, ref) {
    var checked = props.checked, rest = __rest(props, ["checked"]);
    var className = useClassNames(props, [
        'mdc-icon-button',
        {
            'mdc-icon-button--on': checked
        }
    ]);
    return (React.createElement(Icon, __assign({ role: "button", tabIndex: 0 }, rest, { className: className, ref: ref })));
}));
IconButtonRoot.displayName = 'IconButtonRoot';
var IconButtonToggleRoot = withRipple({
    surface: false,
    unbounded: true
})(React.forwardRef(function IconButtonToggleRoot(props, ref) {
    var checked = props.checked, rest = __rest(props, ["checked"]);
    var className = useClassNames(props, [
        'mdc-icon-button',
        {
            'mdc-icon-button--on': checked
        }
    ]);
    return (React.createElement(Tag, __assign({ tag: "button", role: "button", tabIndex: 0 }, rest, { className: className, ref: ref })));
}));
IconButtonToggleRoot.displayName = 'IconButtonToggleRoot';
var IconButtonIcon = React.memo(function IconButtonIcon(props) {
    var on = props.on, rest = __rest(props, ["on"]);
    var className = useClassNames(props, [
        'mdc-icon-button__icon',
        {
            'mdc-icon-button__icon--on': props.on
        }
    ]);
    return React.createElement(Icon, __assign({}, rest, { className: className }));
});
IconButtonIcon.displayName = 'IconButtonIcon';
